==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property failureStrings Strings in the body of the response that indicate a failed login attempt.
 * @property successStrings Strings in the body of the response that indicate a successful login attempt.
 */
public data class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs(
    public val failureStrings: Output<List<String>>,
    public val successStrings: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.builder()
            .failureStrings(failureStrings.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .successStrings(successStrings.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgsBuilder
internal constructor() {
    private var failureStrings: Output<List<String>>? = null

    private var successStrings: Output<List<String>>? = null

    /**
     * @param value Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("stnvbfdveomugiqe")
    public suspend fun failureStrings(`value`: Output<List<String>>) {
        this.failureStrings = value
    }

    @JvmName("dxttnbhfbrlohtux")
    public suspend fun failureStrings(vararg values: Output<String>) {
        this.failureStrings = Output.all(values.asList())
    }

    /**
     * @param values Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("kdwlyoiytlswngmn")
    public suspend fun failureStrings(values: List<Output<String>>) {
        this.failureStrings = Output.all(values)
    }

    /**
     * @param value Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("dwcuxxibwnbyjbed")
    public suspend fun successStrings(`value`: Output<List<String>>) {
        this.successStrings = value
    }

    @JvmName("ehuqlasgfmpywrlr")
    public suspend fun successStrings(vararg values: Output<String>) {
        this.successStrings = Output.all(values.asList())
    }

    /**
     * @param values Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("xseevumxcxcfghad")
    public suspend fun successStrings(values: List<Output<String>>) {
        this.successStrings = Output.all(values)
    }

    /**
     * @param value Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("bymyndauqbrymdos")
    public suspend fun failureStrings(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureStrings = mapped
    }

    /**
     * @param values Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("xmajtdcqecrnbxtn")
    public suspend fun failureStrings(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureStrings = mapped
    }

    /**
     * @param value Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("bhrdfancxutlcwii")
    public suspend fun successStrings(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successStrings = mapped
    }

    /**
     * @param values Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("rkpqxxqeecmxieqh")
    public suspend fun successStrings(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successStrings = mapped
    }

    internal fun build():
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs =
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs(
            failureStrings = failureStrings ?: throw PulumiNullFieldException("failureStrings"),
            successStrings = successStrings ?: throw PulumiNullFieldException("successStrings"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property failureStrings Strings in the body of the response that indicate a failed login attempt.
 * @property successStrings Strings in the body of the response that indicate a successful login attempt.
 */
public data class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs(
    public val failureStrings: Output<List<String>>,
    public val successStrings: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs.builder()
            .failureStrings(failureStrings.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .successStrings(successStrings.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs].
 */
@PulumiTagMarker
public class
WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgsBuilder
internal constructor() {
    private var failureStrings: Output<List<String>>? = null

    private var successStrings: Output<List<String>>? = null

    /**
     * @param value Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("ltffekujnkjahkli")
    public suspend fun failureStrings(`value`: Output<List<String>>) {
        this.failureStrings = value
    }

    @JvmName("edhflylvgrpjgfbw")
    public suspend fun failureStrings(vararg values: Output<String>) {
        this.failureStrings = Output.all(values.asList())
    }

    /**
     * @param values Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("qnebpmssgnrmcjvi")
    public suspend fun failureStrings(values: List<Output<String>>) {
        this.failureStrings = Output.all(values)
    }

    /**
     * @param value Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("uvvbjqroqrhonunn")
    public suspend fun successStrings(`value`: Output<List<String>>) {
        this.successStrings = value
    }

    @JvmName("sgwopyquubdrqunm")
    public suspend fun successStrings(vararg values: Output<String>) {
        this.successStrings = Output.all(values.asList())
    }

    /**
     * @param values Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("diaclsgtawydqwac")
    public suspend fun successStrings(values: List<Output<String>>) {
        this.successStrings = Output.all(values)
    }

    /**
     * @param value Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("jgpwqakymqxsxuwy")
    public suspend fun failureStrings(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureStrings = mapped
    }

    /**
     * @param values Strings in the body of the response that indicate a failed login attempt.
     */
    @JvmName("yoomnileranmbrwn")
    public suspend fun failureStrings(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failureStrings = mapped
    }

    /**
     * @param value Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("fwnpajhfmhwxybdw")
    public suspend fun successStrings(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successStrings = mapped
    }

    /**
     * @param values Strings in the body of the response that indicate a successful login attempt.
     */
    @JvmName("dtfsdkqgivivwphr")
    public suspend fun successStrings(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.successStrings = mapped
    }

    internal fun build(): WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs =
        WebAclRuleStatementManagedRuleGroupStatementManagedRuleGroupConfigAwsManagedRulesAtpRuleSetResponseInspectionBodyContainsArgs(
            failureStrings = failureStrings ?: throw PulumiNullFieldException("failureStrings"),
            successStrings = successStrings ?: throw PulumiNullFieldException("successStrings"),
        )
}
